==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectYaccval.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectyaccval_h
#define objectyaccval_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_yaccval {
  t_adms _adms;
  char* _filename;
  int _filename_isdefault : 1;
  int _lbegin;
  int _lbegin_isdefault : 1;
  int _lend;
  int _lend_isdefault : 1;
  int _wbegin;
  int _wbegin_isdefault : 1;
  int _wend;
  int _wend_isdefault : 1;
  gpointer _usrdata;
  int _usrdata_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_yaccval_getuid (p_yaccval myyaccval);
win32_interface gboolean adms_yaccval_cmp (p_yaccval myyaccval,p_yaccval refyaccval);
win32_interface p_yaccval adms_yaccval_new_1 (char* myfilename);
#define adms_yaccval_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_yaccval_free(item)\
{\
  free(item->_filename);\
  free(item);\
}
win32_interface p_adms adms_yaccval_new_impl (p_adms arguments[]);
win32_interface p_yaccval adms_yaccval_impl (void* member);
#define adms_yaccval(member) ((p_yaccval) (member))
#define adms_yaccval_new adms_yaccval_new_1
#define adms_yaccval_isdefault_filename(yaccval) (adms_yaccval(yaccval)->_filename_isdefault)
#define adms_yaccval_valueof_filename(yaccval) (adms_yaccval(yaccval)->_filename)
#define adms_yaccval_isdefault_lbegin(yaccval) (adms_yaccval(yaccval)->_lbegin_isdefault)
#define adms_yaccval_valueof_lbegin(yaccval) (adms_yaccval(yaccval)->_lbegin)
#define adms_yaccval_isdefault_lend(yaccval) (adms_yaccval(yaccval)->_lend_isdefault)
#define adms_yaccval_valueof_lend(yaccval) (adms_yaccval(yaccval)->_lend)
#define adms_yaccval_isdefault_wbegin(yaccval) (adms_yaccval(yaccval)->_wbegin_isdefault)
#define adms_yaccval_valueof_wbegin(yaccval) (adms_yaccval(yaccval)->_wbegin)
#define adms_yaccval_isdefault_wend(yaccval) (adms_yaccval(yaccval)->_wend_isdefault)
#define adms_yaccval_valueof_wend(yaccval) (adms_yaccval(yaccval)->_wend)
#define adms_yaccval_isdefault_usrdata(yaccval) (adms_yaccval(yaccval)->_usrdata_isdefault)
#define adms_yaccval_valueof_usrdata(yaccval) (adms_yaccval(yaccval)->_usrdata)
#define adms_yaccval_valueof_adms(yaccval) ((p_adms)yaccval)
#define adms_yaccval_valueto_filename(a,b) ((p_yaccval)a)->_filename=(b)
win32_interface void adms_yaccval_valueto_filename_impl (p_yaccval myyaccval,char* _filename);
#define adms_yaccval_valueto_lbegin(a,b) ((p_yaccval)a)->_lbegin=(b)
win32_interface void adms_yaccval_valueto_lbegin_impl (p_yaccval myyaccval,int _lbegin);
#define adms_yaccval_valueto_lend(a,b) ((p_yaccval)a)->_lend=(b)
win32_interface void adms_yaccval_valueto_lend_impl (p_yaccval myyaccval,int _lend);
#define adms_yaccval_valueto_wbegin(a,b) ((p_yaccval)a)->_wbegin=(b)
win32_interface void adms_yaccval_valueto_wbegin_impl (p_yaccval myyaccval,int _wbegin);
#define adms_yaccval_valueto_wend(a,b) ((p_yaccval)a)->_wend=(b)
win32_interface void adms_yaccval_valueto_wend_impl (p_yaccval myyaccval,int _wend);
#define adms_yaccval_valueto_usrdata(a,b) ((p_yaccval)a)->_usrdata=(b)
win32_interface void adms_yaccval_valueto_usrdata_impl (p_yaccval myyaccval,gpointer _usrdata);
#endif /* objectyaccval_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectYaccval.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectyaccval_h
#define objectyaccval_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_yaccval {
  t_adms _adms;
  char* _filename;
  int _filename_isdefault : 1;
  int _lbegin;
  int _lbegin_isdefault : 1;
  int _lend;
  int _lend_isdefault : 1;
  int _wbegin;
  int _wbegin_isdefault : 1;
  int _wend;
  int _wend_isdefault : 1;
  p_adms _usrdata;
  int _usrdata_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_yaccval_uid (p_yaccval myyaccval);
win32_interface int adms_yaccval_cmp (p_yaccval myyaccval,p_yaccval refyaccval);
win32_interface p_yaccval adms_yaccval_new(const char* myfilename);
win32_interface p_adms adms_yaccval_new_impl (p_adms arguments[]);
#define adms_yaccval(member) ((p_yaccval) (member))
#define adms_yaccval_isdefault_filename(yaccval) (adms_yaccval(yaccval)->_filename_isdefault)
#define adms_yaccval_valueof_filename(yaccval) (adms_yaccval(yaccval)->_filename)
#define adms_yaccval_isdefault_lbegin(yaccval) (adms_yaccval(yaccval)->_lbegin_isdefault)
#define adms_yaccval_valueof_lbegin(yaccval) (adms_yaccval(yaccval)->_lbegin)
#define adms_yaccval_isdefault_lend(yaccval) (adms_yaccval(yaccval)->_lend_isdefault)
#define adms_yaccval_valueof_lend(yaccval) (adms_yaccval(yaccval)->_lend)
#define adms_yaccval_isdefault_wbegin(yaccval) (adms_yaccval(yaccval)->_wbegin_isdefault)
#define adms_yaccval_valueof_wbegin(yaccval) (adms_yaccval(yaccval)->_wbegin)
#define adms_yaccval_isdefault_wend(yaccval) (adms_yaccval(yaccval)->_wend_isdefault)
#define adms_yaccval_valueof_wend(yaccval) (adms_yaccval(yaccval)->_wend)
#define adms_yaccval_isdefault_usrdata(yaccval) (adms_yaccval(yaccval)->_usrdata_isdefault)
#define adms_yaccval_valueof_usrdata(yaccval) (adms_yaccval(yaccval)->_usrdata)
#define adms_yaccval_valueof_adms(yaccval) ((p_adms)yaccval)
win32_interface inline void adms_yaccval_valueto_filename (p_yaccval myyaccval,const char* _filename);
win32_interface inline void adms_yaccval_valueto_lbegin (p_yaccval myyaccval,int _lbegin);
win32_interface inline void adms_yaccval_valueto_lend (p_yaccval myyaccval,int _lend);
win32_interface inline void adms_yaccval_valueto_wbegin (p_yaccval myyaccval,int _wbegin);
win32_interface inline void adms_yaccval_valueto_wend (p_yaccval myyaccval,int _wend);
win32_interface inline void adms_yaccval_valueto_usrdata (p_yaccval myyaccval,p_adms _usrdata);
win32_interface inline void adms_yaccval_free(p_yaccval myyaccval);
#endif /* objectyaccval_h */
